@@ -1164,3 +1164,334 @@ get_plot_body_pdf <- function(plt, plot_path, talign, rs,
   
 }
 
+
+
+# Write DOCX Functions -----------------------------------------------------
+
+
+#' @description A function to output strings for plot content
+#' @details Basic logic is to write the plot as a png file to a temporary
+#' location, then put a token in the text that references the temp location.
+#' Later code will pick up the image and insert it into the report.  Blank
+#' lines are generated to fill up the page based on a calculation using
+#' the plot height and width.
+#' @param rs The Report Spec
+#' @param cntnt The text content to output
+#' @param lpg_rows Last page rows.
+#' @noRd
+create_plot_pages_docx<- function(rs, cntnt, lpg_rows, tmp_dir) {
+  
+  if (!"report_spec" %in% class(rs))
+    stop("Report spec expected for parameter rs")
+  
+  if (!"report_content" %in% class(cntnt))
+    stop("Report Content expected for parameter cntnt")
+
+  pgs <- list()
+  cnts <- c()
+  imgs <- list()
+  
+  relIndex <- rs$relIndex
+  
+  # Get plot spec 
+  plt <- cntnt$object
+  p <- plt$plot
+  
+  
+  if (any(class(p) %in% c("character"))) {
+    
+    tmp_nm <- tempfile(tmpdir = tmp_dir, fileext = ".jpg")
+    
+    file.copy(p, tmp_nm, overwrite = TRUE)
+    
+    # Get rtf page bodies
+    res <- get_plot_body_docx(plt, tmp_nm, cntnt$align, rs,
+                              lpg_rows, cntnt$blank_row, NULL, NULL, 
+                              FALSE, relIndex)
+    
+    pgs[[length(pgs) + 1]] <- res$docx
+    cnts[[length(cnts) + 1]] <- res$lines
+    
+    relID <- paste0("rId", relIndex)
+    imgs[[relID]] <- tmp_nm
+    relIndex <- relIndex + 1
+    
+  } else {
+    
+    
+    # Get data in case we need it for page by
+    raw <- plt$plot$data
+    
+    # Determine if there is a page by
+    pgby <- NULL
+    if (!is.null(rs$page_by))
+      pgby <- rs$page_by
+    if (!is.null(plt$page_by))
+      pgby <- plt$page_by
+    
+    if (!is.null(pgby)) {
+      if (!pgby$var %in% names(raw))
+        stop("Page by variable not found in plot data.")
+      
+      dat_lst <- split(raw, raw[[pgby$var]])
+    } else {
+      dat_lst <- list(raw) 
+    }
+    
+    u <- ifelse(rs$units == "inches", "in", rs$units)
+    p <- plt$plot
+    ret <- list()
+    cntr <- 1
+    
+    
+    for (dat in dat_lst) {
+      
+      tmp_nm <- tempfile(tmpdir = tmp_dir, fileext = ".jpg")
+      
+      p$data <- dat
+      
+      pgval <- NULL
+      if (!is.null(pgby)) {
+        # print(pgby$var)
+        # print(dat)
+        pgval <- dat[1, c(pgby$var)]
+      }
+      
+      # Save plot to temp file
+      if (any(class(p) %in% c("ggcoxzph", "ggsurv"))) {
+        
+        # Deal with survival plots
+        ggplot2::ggsave(tmp_nm, gridExtra::arrangeGrob(grobs = p), 
+                        width =  plt$width, height = plt$height, 
+                        dpi = 300, units = u )
+        
+        
+      } else {
+        
+        # Any other type of plots
+        ggplot2::ggsave(tmp_nm, p, width =  plt$width, height = plt$height, 
+                        dpi = 300, units = u)
+      }
+      
+      # Get rtf page bodies
+      res <- get_plot_body_docx(plt, tmp_nm, cntnt$align, rs,
+                                lpg_rows, cntnt$blank_row, pgby, pgval, 
+                                cntr < length(dat_lst), relIndex)
+      
+      pgs[[length(pgs) + 1]] <- res$docx
+      cnts[[length(cnts) + 1]] <- res$lines
+      
+      relID <- paste0("rId", relIndex)
+      imgs[[relID]] <- tmp_nm
+      relIndex <- relIndex + 1
+      
+      cntr <- cntr + 1
+      
+    }
+  }
+  
+  ret <- list(docx = pgs,
+              lines = cnts,
+              images = imgs)
+  
+  return(ret)
+}
+
+#' Create list of vectors of strings for each page 
+#' @noRd
+get_plot_body_docx <- function(plt, plot_path, talign, rs,
+                               lpg_rows, content_blank_row, pgby, pgval, 
+                               wrap_flag, rID) {
+  
+  conv <- rs$twip_conversion
+  
+  # Default to content width
+  wth <- rs$content_size[["width"]] 
+  
+  # If user supplies a width, override default
+  if (!is.null(plt$width))
+    wth <- plt$width
+  
+  
+  # Get titles and footnotes
+  ttls <- get_titles_docx(plt$titles, wth, rs, talign,
+                          content_brdrs = plt$borders) 
+  ttl_hdr <- get_title_header_docx(plt$title_hdr, wth, rs, talign)
+  
+  exclude_top <- NULL
+  if (ttls$border_flag == TRUE | ttl_hdr$border_flag == TRUE) {
+    exclude_top <- "top"
+    
+    pgbys <- get_page_by_docx(pgby, wth, pgval, rs, talign, TRUE)
+  } else {
+    
+    pgbys <- get_page_by_docx(pgby, wth, pgval, rs, talign, FALSE)
+  }
+  
+  if (is.null(exclude_top)) {
+    if (pgbys$border_flag)
+      exclude_top <- "top"
+    
+  }
+  
+  algn <- talign
+  if (talign == "centre")
+    algn <- "center"
+  
+  # algn <- "\\qc" 
+  # This height and width is for the image scaling.
+  u <- rs$units
+  iconv <- 914400  # Image unit conversion. Not even sure what units this is.
+  if (u == "inches") {
+    hgth <- (plt$height - .2) * iconv 
+    wdth <- (plt$width - .2) * iconv 
+    
+  } else {
+    hgth <- (cin(plt$height) - .2) * iconv 
+    wdth <- (cin(plt$width) - .2) * iconv
+    
+  }
+  
+  # Get image RTF codes
+  img <- get_image_docx(rID, algn, hgth, wdth)
+  
+  
+  # Get indent codes for alignment
+  ta <- get_indent_docx(talign, rs$line_size, round(wth * conv), 
+                        rs$base_indent, plt$borders, conv)
+  
+  grd <- get_col_grid(c(img = round(wth * conv)), 1)
+  
+
+  # Get border codes
+  tb <- get_table_borders_docx(plt$borders)
+  
+  tcb <- paste('<w:tcBorders>', 
+               ifelse(any(plt$borders %in% c("all", "outside", "top")),
+							'<w:top w:val="single" w:sz="4" w:space="0" w:color="auto"/>', ""),
+							ifelse(any(plt$borders %in% c("all", "outside", "bottom")),
+							'<w:bottom w:val="single" w:sz="4" w:space="0" w:color="auto"/>', ""),
+						  '</w:tcBorders>')
+  
+  # Concat all header codes
+  hd <- paste0("<w:tbl>",  "<w:tblPr>",
+               '<w:tblStyle w:val="TableGrid"/>',
+               rs$cell_margin,
+               '<w:tblW w:w="', round(wth * conv),'"',
+               ' w:type="dxa"/>', ta, tb,
+               "</w:tblPr>\n", grd,
+               "<w:tr><w:tc>\n",
+               '<w:tcPr><w:tcW w:w="', round(wth * conv),'"/>', tcb,'</w:tcPr>')
+  
+  ft <- paste0("</w:tc></w:tr></w:tbl>\n")
+  
+  
+  # Concat RTF codes for image
+  img <- paste0(hd, img, ft)
+  
+  # ** Do something with this **
+  imght <- floor(plt$height / rs$line_height)
+  
+  # Add blank above content if requested
+  a <- NULL
+  if (content_blank_row %in% c("both", "above"))
+    a <- rs$blank_row
+  
+  
+  # Get sum of all items to this point
+  lns <- sum(length(a), ttls$lines, ttl_hdr$lines, pgbys$lines, imght)
+  
+  if ("bottom" %in% get_outer_borders(plt$borders))
+    extp <- TRUE
+  else 
+    extp <- FALSE 
+  
+  # Get footnotes, filler, and content blank line
+  ftnts <- get_page_footnotes_docx(rs, plt, wth, lpg_rows, lns,
+                                   wrap_flag, content_blank_row, talign, extp,
+                                   content_brdrs = plt$borders)
+  
+  # Combine titles, blanks, body, and footnotes
+  rws <- c(a, ttls$docx, ttl_hdr$docx, pgbys$docx, img)
+  
+  
+  # Combine everything
+  rws <- c(rws, ftnts$docx)
+  lns <- sum(lns, ftnts$lines)
+  
+  
+  # Page list
+  ret <- list(docx = rws,
+              lines = lns)  
+  
+  
+  return(ret)
+  
+}
+
+
+get_image_docx <- function(id, algn, hgth, wdth) {
+ 
+  
+ ret <- paste0('<w:p>',
+               '<w:pPr><w:jc w:val="', algn, '"/></w:pPr>',
+    '<w:r>
+    <w:rPr>
+    <w:noProof/>
+    </w:rPr>
+    <w:drawing>
+    <wp:inline distT="0" distB="0" distL="0" distR="0" 
+       wp14:anchorId="53259B4E" wp14:editId="79F9BC2E">
+      <wp:extent cx="', wdth, '" cy="', hgth, '"/>
+        <wp:effectExtent l="0" t="0" r="0" b="0"/>
+          <wp:docPr id="', id, '" name="Picture ', id, '"/>
+            <wp:cNvGraphicFramePr>
+            <a:graphicFrameLocks
+          xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" noChangeAspect="1"/>
+            </wp:cNvGraphicFramePr>
+            <a:graphic
+          xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main">
+            <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/picture">
+            <pic:pic
+          xmlns:pic="http://schemas.openxmlformats.org/drawingml/2006/picture">
+            <pic:nvPicPr>
+            <pic:cNvPr id="', id, '" name="Picture ', id, '"/>
+            <pic:cNvPicPr/>
+            </pic:nvPicPr>
+            <pic:blipFill>
+            <a:blip r:embed="rId', id, '" cstate="print">
+            <a:extLst>
+            <a:ext uri="{28A0092B-C50C-407E-A947-70E740481C1C}">
+            <a14:useLocalDpi
+          xmlns:a14="http://schemas.microsoft.com/office/drawing/2010/main" val="0"/>
+            </a:ext>
+            </a:extLst>
+            </a:blip>
+            <a:stretch>
+            <a:fillRect/>
+            </a:stretch>
+            </pic:blipFill>
+            <pic:spPr>
+            <a:xfrm>
+            <a:off x="0" y="0"/>
+            <a:ext cx="', wdth, '" cy="', hgth, '"/>
+            </a:xfrm>
+            <a:prstGeom prst="rect">
+            <a:avLst/>
+            </a:prstGeom>
+            </pic:spPr>
+            </pic:pic>
+            </a:graphicData>
+            </a:graphic>
+            </wp:inline>
+            </w:drawing>
+            </w:r>
+            </w:p>')
+ 
+ #ret <- paste0('<w:p><w:r><w:t>Hello</w:t></w:r></w:p>')
+ 
+ 
+ return(ret)
+  
+}
+
